package com.zg.project.wisdom.service;

import java.util.List;
import com.zg.project.wisdom.domain.GysJh;

/**
 * 供应计划Service接口
 * 
 * @author zg
 * @date 2025-05-28
 */
public interface IGysJhService 
{
    /**
     * 查询供应计划
     * 
     * @param id 供应计划主键
     * @return 供应计划
     */
    public GysJh selectGysJhById(Long id);

    /**
     * 查询供应计划列表
     * 
     * @param gysJh 供应计划
     * @return 供应计划集合
     */
    public List<GysJh> selectGysJhList(GysJh gysJh);

    /**
     * 新增供应计划
     * 
     * @param gysJh 供应计划
     * @return 结果
     */
    public int insertGysJh(GysJh gysJh);

    /**
     * 修改供应计划
     * 
     * @param gysJh 供应计划
     * @return 结果
     */
    public int updateGysJh(GysJh gysJh);

    /**
     * 批量删除供应计划
     * 
     * @param ids 需要删除的供应计划主键集合
     * @return 结果
     */
    public int deleteGysJhByIds(Long[] ids);

    /**
     * 删除供应计划信息
     * 
     * @param id 供应计划主键
     * @return 结果
     */
    public int deleteGysJhById(Long id);

    /**
     * 供应计划导入
     * @param jhList
     * @param operName
     * @return
     */
    String importGysJhList(List<GysJh> jhList, String operName);

    /**
     * 根据sapNo查询
     * @param sapNo
     * @return
     */
    List<GysJh> getBySapNo(String sapNo);
}
